@@ -32,5 +32,5 @@ if __name__ == '__main__':
     )
     
     for image, suffix in generator:
-        image.save(f"out_{suffix}.png")
+        image.save("out_{}.png".format(suffix))
         image.close()
