@@ -2,7 +2,7 @@
 # SPDX-FileCopyrightText: 2022 geisserml <geisserml@gmail.com>
 # SPDX-License-Identifier: Apache-2.0 OR BSD-3-Clause
 
-from setup_base import *
+from _setup_base import *
 
 class bdist (BDistBase):
     def finalize_options(self):
