@@ -3,17 +3,15 @@
 # SPDX-License-Identifier: Apache-2.0 OR BSD-3-Clause
 
 import os
-import platform
+import sysconfig
 import build_pdfium
-from setup_base import *
+from _setup_base import *
 
 
 class bdist (BDistBase):
     def finalize_options(self):
         BDistBase.finalize_options(self)
-        plat_name = f"{platform.system()}_{platform.machine()}".lower()
-        plat_name = plat_name.replace('-','_').replace('.','_')
-        self.plat_name = plat_name
+        self.plat_name = sysconfig.get_platform()
 
 
 def lib_setup(libname):
@@ -24,7 +22,7 @@ def lib_setup(libname):
 
 
 def get_binary():
-    libpath = build_pdfium.find_lib(build_pdfium.OutputDir)
+    libpath = build_pdfium.find_lib(directory=build_pdfium.OutputDir)
     return os.path.basename(libpath)
 
 
@@ -32,7 +30,6 @@ def main():
     libname = get_binary()
     build(lambda: lib_setup(libname), build_pdfium.OutputDir)
     binary_path = join(SourceTree, 'src', 'pypdfium2', libname)
-    os.remove(binary_path)
 
 
 if __name__ == '__main__':
